@@ -50,6 +50,7 @@ class account():
     INACTIVE = 2
     status = ""
     avatar_size = 60
+    friendCount = 0
     lat=None
     long = None
     location = True
@@ -149,23 +150,31 @@ class account():
     def setProfileInfo(self):
         try:
             user = self.getProfileInfo(self.accountdata.username)
-            self.controller.ui.profileTweetsLabel.set_text("TweetCount: " +str(user.GetStatusesCount()))
-            self.controller.ui.profileFollowerCount.set_text("Followers: "+str(user.GetFollowersCount()))
-            self.controller.ui.profileFollowingCount.set_text("Following: " +str(user.GetFriendsCount()))
-            self.controller.ui.accountNameLabel.set_text(self.accountdata.username)
-            self.controller.ui.profileLastTweet.set_text(user.GetStatus().GetText())
+            self.controller.ui.profileTweetsLabel.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">TweetCount: </span>" +str(user.GetStatusesCount()))
+            self.controller.ui.profileFollowerCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Followers: </span>"+str(user.GetFollowersCount()))
+            self.controller.ui.profileFollowingCount.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Following: </span>" +str(user.GetFriendsCount()))
+            self.friendCount = user.GetFriendsCount()
+            self.controller.ui.accountNameLabel.set_markup(self.accountdata.username)
+            status = user.GetStatus()
+            print "formatting tweet"
+            source = self.getSourceAppname(status.GetSource())
+            formattedTweet =  self.format_tweet(user.GetName(), status.GetText(), status.GetCreatedAt(), source, status.GetInReplyToScreenName())
+            
+            self.controller.ui.profileLastTweet.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Last Tweet: </span>" + formattedTweet)
+            
             if (user.GetStatus().GetPlace() != None):
-                self.controller.ui.profileLocation.set_text(user.GetStatus().GetPlace().name)
+                self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetStatus().GetPlace().name)
             else:
                 if (user.GetLocation() != None):
-                    self.controller.ui.profileLocation.set_text(user.GetLocation())
+                    self.controller.ui.profileLocation.set_markup("<span weight = 'bold' foreground=\"#6bd3ff\">Location: </span>" +user.GetLocation())
                 
             avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
             avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
             #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
             self.controller.ui.profileImage.set_from_pixbuf(avatar)  
-        except AttributeError:
+        except AttributeError, ae:
             print "Failed to load profile info" 
+            print ae
             
     def getAccountData(self):
         return self.accountdata
@@ -554,32 +563,41 @@ class account():
         self.friendsstore.clear()
         try:
             #by default we get newer tweets
-            data = self.api.GetFriends()
+            page=0
+            followers = self.friendCount
+            moreFriends=True
+            while (moreFriends):
+                data = self.api.GetFriends(page=page)
+                
+                if ((followers -100) > 0):
+                    page=page+1
+                else:
+                    moreFriends=False
+                if (data != None):
+                    for x in data:
+                        #it's possible to follow someone that has never updated their status
+                        if (x.status != None):
+                            status = x.status.text
+                            tweettime = x.status.created_at
+                            source = x.status.source
+                        else:
+                            status = ""
+                            tweettime = ""
+                            status = ""
+                        status = self.escapeText(status)
+                        source = self.getSourceAppname(source)
+                        pic = self.set_pic_for_id(str(x.id), x.GetScreenName(), x.GetProfileImageUrl())
+                        created_at = self.parse_time(tweettime)
+                        formatted_ts = self.format_timestamp(created_at)
+                        formatted_tweet = self.format_tweet(x.screen_name, status, formatted_ts, source, None)
+                        self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", long(x.id), "friend", tweettime, "", source, pic, formatted_tweet])
+                        receive_count = receive_count + 1
+    
+                    if (receive_count > 0):
+                        note = osso.SystemNote(self.osso_c)
+                        result = note.system_note_infoprint(str(receive_count) + " Friends Received")
+                    #update friend/follower counts etc
 
-            if (data != None):
-                for x in data:
-                    #it's possible to follow someone that has never updated their status
-                    if (x.status != None):
-                        status = x.status.text
-                        tweettime = x.status.created_at
-                        source = x.status.source
-                    else:
-                        status = ""
-                        tweettime = ""
-                        status = ""
-                    status = self.escapeText(status)
-                    source = self.getSourceAppname(source)
-                    pic = self.set_pic_for_id(str(x.id), x.GetScreenName(), x.GetProfileImageUrl())
-                    created_at = self.parse_time(tweettime)
-                    formatted_ts = self.format_timestamp(created_at)
-                    formatted_tweet = self.format_tweet(x.screen_name, status, formatted_ts, source, None)
-                    self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", long(x.id), "friend", tweettime, "", source, pic, formatted_tweet])
-                    receive_count = receive_count + 1
-
-                if (receive_count > 0):
-                    note = osso.SystemNote(self.osso_c)
-                    result = note.system_note_infoprint(str(receive_count) + " Friends Received")
-                #update friend/follower counts etc
                 self.setProfileInfo()
         except IOError, e:
             print "error"
