@@ -418,29 +418,31 @@ class Status(object):
     Returns:
       A twitter.Status instance
     '''
-    if 'user' in data:
-      user = User.NewFromJsonDict(data['user'])
+    if data != None:
+        if 'user' in data:
+          user = User.NewFromJsonDict(data['user'])
+        else:
+          user = None
+        if 'place' in data:
+          if (data['place'] != None):
+              place = Place.NewFromJsonDict(data['place'])
+          else:
+              place=None
+        else:
+          place = None
+        return Status(created_at=data.get('created_at', None),
+                      favorited=data.get('favorited', None),
+                      id=data.get('id', None),
+                      text=data.get('text', None),
+                      place=place,
+                      in_reply_to_screen_name=data.get('in_reply_to_screen_name', None),
+                      in_reply_to_user_id=data.get('in_reply_to_user_id', None),
+                      in_reply_to_status_id=data.get('in_reply_to_status_id', None),
+                      truncated=data.get('truncated', None),
+                      source=data.get('source', None),
+                      user=user)
     else:
-      user = None
-    if 'place' in data:
-      if (data['place'] != None):
-          place = Place.NewFromJsonDict(data['place'])
-      else:
-          place=None
-    else:
-      place = None
-    return Status(created_at=data.get('created_at', None),
-                  favorited=data.get('favorited', None),
-                  id=data.get('id', None),
-                  text=data.get('text', None),
-                  place=place,
-                  in_reply_to_screen_name=data.get('in_reply_to_screen_name', None),
-                  in_reply_to_user_id=data.get('in_reply_to_user_id', None),
-                  in_reply_to_status_id=data.get('in_reply_to_status_id', None),
-                  truncated=data.get('truncated', None),
-                  source=data.get('source', None),
-                  user=user)
-
+        return None
 
 class User(object):
   '''A class representing the User structure used by the twitter API.
