@@ -202,7 +202,9 @@ class Witter():
             mymode =FremantleRotation.AUTOMATIC
         
         self.rotation = FremantleRotation("Witter", self.ui.window, mode=mymode)
-        self.activeAccount.setProfileInfo()
+        self.profileUpdateThread = witter.RefreshTask(self.setProfile, 0, None)
+        self.profileUpdateThread.refresh()
+        
 
     def quit(self, *args):
         #this is our end method called when window is closed
@@ -899,7 +901,8 @@ class Witter():
 
     def startLocation(self, get_older=False, more=0, autoval=None):
         self.activeAccount.updateLocation()
-        
+    def setProfile(self, get_older=False, more=0, autoval=None):
+        self.activeAccount.setProfileInfo()   
         
     def getTweetsWrapper(self, get_older=False, more=0, autoval=None):
         self.ui.showBusy(1)
